Parses the provided uuid into a list of byte values as a List<int>.
Can optionally be provided a buffer to write into and
a positional offset for where to start inputting into the buffer.
Parses the provided uuid into a list of byte values as a Uint8List.
Can optionally be provided a buffer to write into and
a positional offset for where to start inputting into the buffer.
Throws FormatException if the UUID is invalid. Optionally you can set
validate to false to disable validation of the UUID before parsing.
Set noDashes to true when parsing a 32-character UUID without dashes.
Parses the provided uuid into a list of byte values as a List<int>.
Can optionally be provided a buffer to write into and
a positional offset for where to start inputting into the buffer.
Parses the provided uuid into a list of byte values as a Uint8List.
Can optionally be provided a buffer to write into and
a positional offset for where to start inputting into the buffer.
Throws FormatException if the hexadecimal format is invalid.
UUID version and variant bits are not validated.
Optionally you can set validate to false to disable
validation of the UUID before parsing.
Set noDashes to true when parsing 32 hexadecimal characters without
dashes.