generateFromBytes method
v5FromBytes() Generates a namespace & name-based version 5 UUID from binary data
By default it will generate a string based on a provided uuid namespace and binary name data, and will return a string.
The namespace parameter is the UUID namespace (as a String).
The name parameter is a Uint8List containing arbitrary binary data.
This allows for generating UUIDs from raw bytes as per RFC 4122 / RFC 9562.
Implementation
String generateFromBytes(String? namespace, Uint8List? name,
{V5Options? options}) {
var nameBytes = name ?? Uint8List(0);
return _generateFromBytes(namespace, nameBytes, options: options);
}